==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/OriginGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin

import com.pulumi.azurenative.cdn.kotlin.outputs.HealthProbeParametersResponse
import com.pulumi.azurenative.cdn.kotlin.outputs.ResourceReferenceResponse
import com.pulumi.azurenative.cdn.kotlin.outputs.ResponseBasedOriginErrorDetectionParametersResponse
import com.pulumi.azurenative.cdn.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.cdn.kotlin.outputs.HealthProbeParametersResponse.Companion.toKotlin as healthProbeParametersResponseToKotlin
import com.pulumi.azurenative.cdn.kotlin.outputs.ResourceReferenceResponse.Companion.toKotlin as resourceReferenceResponseToKotlin
import com.pulumi.azurenative.cdn.kotlin.outputs.ResponseBasedOriginErrorDetectionParametersResponse.Companion.toKotlin as responseBasedOriginErrorDetectionParametersResponseToKotlin
import com.pulumi.azurenative.cdn.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [OriginGroup].
 */
@PulumiTagMarker
public class OriginGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: OriginGroupArgs = OriginGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend OriginGroupArgsBuilder.() -> Unit) {
        val builder = OriginGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): OriginGroup {
        val builtJavaResource = com.pulumi.azurenative.cdn.OriginGroup(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return OriginGroup(builtJavaResource)
    }
}

/**
 * Origin group comprising of origins is used for load balancing to origins when the content cannot be served from CDN.
 * Azure REST API version: 2023-05-01. Prior API version in Azure Native 1.x: 2020-09-01.
 * Other available API versions: 2023-07-01-preview.
 * ## Example Usage
 * ### OriginGroups_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var originGroup = new AzureNative.Cdn.OriginGroup("originGroup", new()
 *     {
 *         EndpointName = "endpoint1",
 *         HealthProbeSettings = new AzureNative.Cdn.Inputs.HealthProbeParametersArgs
 *         {
 *             ProbeIntervalInSeconds = 120,
 *             ProbePath = "/health.aspx",
 *             ProbeProtocol = AzureNative.Cdn.ProbeProtocol.Http,
 *             ProbeRequestType = AzureNative.Cdn.HealthProbeRequestType.GET,
 *         },
 *         OriginGroupName = "origingroup1",
 *         Origins = new[]
 *         {
 *             new AzureNative.Cdn.Inputs.ResourceReferenceArgs
 *             {
 *                 Id = "/subscriptions/subid/resourceGroups/RG/providers/Microsoft.Cdn/profiles/profile1/endpoints/endpoint1/origins/origin1",
 *             },
 *         },
 *         ProfileName = "profile1",
 *         ResourceGroupName = "RG",
 *         ResponseBasedOriginErrorDetectionSettings = new AzureNative.Cdn.Inputs.ResponseBasedOriginErrorDetectionParametersArgs
 *         {
 *             ResponseBasedDetectedErrorTypes = AzureNative.Cdn.ResponseBasedDetectedErrorTypes.TcpErrorsOnly,
 *             ResponseBasedFailoverThresholdPercentage = 10,
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/cdn/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := cdn.NewOriginGroup(ctx, "originGroup", &cdn.OriginGroupArgs{
 * 			EndpointName: pulumi.String("endpoint1"),
 * 			HealthProbeSettings: &cdn.HealthProbeParametersArgs{
 * 				ProbeIntervalInSeconds: pulumi.Int(120),
 * 				ProbePath:              pulumi.String("/health.aspx"),
 * 				ProbeProtocol:          cdn.ProbeProtocolHttp,
 * 				ProbeRequestType:       cdn.HealthProbeRequestTypeGET,
 * 			},
 * 			OriginGroupName: pulumi.String("origingroup1"),
 * 			Origins: []cdn.ResourceReferenceArgs{
 * 				{
 * 					Id: pulumi.String("/subscriptions/subid/resourceGroups/RG/providers/Microsoft.Cdn/profiles/profile1/endpoints/endpoint1/origins/origin1"),
 * 				},
 * 			},
 * 			ProfileName:       pulumi.String("profile1"),
 * 			ResourceGroupName: pulumi.String("RG"),
 * 			ResponseBasedOriginErrorDetectionSettings: &cdn.ResponseBasedOriginErrorDetectionParametersArgs{
 * 				ResponseBasedDetectedErrorTypes:          cdn.ResponseBasedDetectedErrorTypesTcpErrorsOnly,
 * 				ResponseBasedFailoverThresholdPercentage: pulumi.Int(10),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.cdn.OriginGroup;
 * import com.pulumi.azurenative.cdn.OriginGroupArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var originGroup = new OriginGroup("originGroup", OriginGroupArgs.builder()
 *             .endpointName("endpoint1")
 *             .healthProbeSettings(Map.ofEntries(
 *                 Map.entry("probeIntervalInSeconds", 120),
 *                 Map.entry("probePath", "/health.aspx"),
 *                 Map.entry("probeProtocol", "Http"),
 *                 Map.entry("probeRequestType", "GET")
 *             ))
 *             .originGroupName("origingroup1")
 *             .origins(Map.of("id", "/subscriptions/subid/resourceGroups/RG/providers/Microsoft.Cdn/profiles/profile1/endpoints/endpoint1/origins/origin1"))
 *             .profileName("profile1")
 *             .resourceGroupName("RG")
 *             .responseBasedOriginErrorDetectionSettings(Map.ofEntries(
 *                 Map.entry("responseBasedDetectedErrorTypes", "TcpErrorsOnly"),
 *                 Map.entry("responseBasedFailoverThresholdPercentage", 10)
 *             ))
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:cdn:OriginGroup origingroup1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Cdn/profiles/{profileName}/endpoints/{endpointName}/originGroups/{originGroupName}
 * ```
 */
public class OriginGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.cdn.OriginGroup,
) : KotlinCustomResource(javaResource, OriginGroupMapper) {
    /**
     * Health probe settings to the origin that is used to determine the health of the origin.
     */
    public val healthProbeSettings: Output<HealthProbeParametersResponse>?
        get() = javaResource.healthProbeSettings().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> healthProbeParametersResponseToKotlin(args0) })
            }).orElse(null)
        })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The source of the content being delivered via CDN within given origin group.
     */
    public val origins: Output<List<ResourceReferenceResponse>>
        get() = javaResource.origins().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    resourceReferenceResponseToKotlin(args0)
                })
            })
        })

    /**
     * Provisioning status of the origin group.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource status of the origin group.
     */
    public val resourceState: Output<String>
        get() = javaResource.resourceState().applyValue({ args0 -> args0 })

    /**
     * The JSON object that contains the properties to determine origin health using real requests/responses. This property is currently not supported.
     */
    public val responseBasedOriginErrorDetectionSettings:
        Output<ResponseBasedOriginErrorDetectionParametersResponse>?
        get() = javaResource.responseBasedOriginErrorDetectionSettings().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    responseBasedOriginErrorDetectionParametersResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Read only system data
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Time in minutes to shift the traffic to the endpoint gradually when an unhealthy endpoint comes healthy or a new endpoint is added. Default is 10 mins. This property is currently not supported.
     */
    public val trafficRestorationTimeToHealedOrNewEndpointsInMinutes: Output<Int>?
        get() =
            javaResource.trafficRestorationTimeToHealedOrNewEndpointsInMinutes().applyValue({ args0 ->
                args0.map({ args0 -> args0 }).orElse(null)
            })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object OriginGroupMapper : ResourceMapper<OriginGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.cdn.OriginGroup::class == javaResource::class

    override fun map(javaResource: Resource): OriginGroup = OriginGroup(
        javaResource as
            com.pulumi.azurenative.cdn.OriginGroup,
    )
}

/**
 * @see [OriginGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [OriginGroup].
 */
public suspend fun originGroup(name: String, block: suspend OriginGroupResourceBuilder.() -> Unit):
    OriginGroup {
    val builder = OriginGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [OriginGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun originGroup(name: String): OriginGroup {
    val builder = OriginGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/OriginGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin

import com.pulumi.azurenative.cdn.kotlin.outputs.HealthProbeParametersResponse
import com.pulumi.azurenative.cdn.kotlin.outputs.ResourceReferenceResponse
import com.pulumi.azurenative.cdn.kotlin.outputs.ResponseBasedOriginErrorDetectionParametersResponse
import com.pulumi.azurenative.cdn.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.cdn.kotlin.outputs.HealthProbeParametersResponse.Companion.toKotlin as healthProbeParametersResponseToKotlin
import com.pulumi.azurenative.cdn.kotlin.outputs.ResourceReferenceResponse.Companion.toKotlin as resourceReferenceResponseToKotlin
import com.pulumi.azurenative.cdn.kotlin.outputs.ResponseBasedOriginErrorDetectionParametersResponse.Companion.toKotlin as responseBasedOriginErrorDetectionParametersResponseToKotlin
import com.pulumi.azurenative.cdn.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [OriginGroup].
 */
@PulumiTagMarker
public class OriginGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: OriginGroupArgs = OriginGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend OriginGroupArgsBuilder.() -> Unit) {
        val builder = OriginGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): OriginGroup {
        val builtJavaResource = com.pulumi.azurenative.cdn.OriginGroup(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return OriginGroup(builtJavaResource)
    }
}

/**
 * Origin group comprising of origins is used for load balancing to origins when the content cannot be served from CDN.
 * Azure REST API version: 2023-05-01. Prior API version in Azure Native 1.x: 2020-09-01.
 * Other available API versions: 2023-07-01-preview, 2024-02-01.
 * ## Example Usage
 * ### OriginGroups_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var originGroup = new AzureNative.Cdn.OriginGroup("originGroup", new()
 *     {
 *         EndpointName = "endpoint1",
 *         HealthProbeSettings = new AzureNative.Cdn.Inputs.HealthProbeParametersArgs
 *         {
 *             ProbeIntervalInSeconds = 120,
 *             ProbePath = "/health.aspx",
 *             ProbeProtocol = AzureNative.Cdn.ProbeProtocol.Http,
 *             ProbeRequestType = AzureNative.Cdn.HealthProbeRequestType.GET,
 *         },
 *         OriginGroupName = "origingroup1",
 *         Origins = new[]
 *         {
 *             new AzureNative.Cdn.Inputs.ResourceReferenceArgs
 *             {
 *                 Id = "/subscriptions/subid/resourceGroups/RG/providers/Microsoft.Cdn/profiles/profile1/endpoints/endpoint1/origins/origin1",
 *             },
 *         },
 *         ProfileName = "profile1",
 *         ResourceGroupName = "RG",
 *         ResponseBasedOriginErrorDetectionSettings = new AzureNative.Cdn.Inputs.ResponseBasedOriginErrorDetectionParametersArgs
 *         {
 *             ResponseBasedDetectedErrorTypes = AzureNative.Cdn.ResponseBasedDetectedErrorTypes.TcpErrorsOnly,
 *             ResponseBasedFailoverThresholdPercentage = 10,
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/cdn/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := cdn.NewOriginGroup(ctx, "originGroup", &cdn.OriginGroupArgs{
 * 			EndpointName: pulumi.String("endpoint1"),
 * 			HealthProbeSettings: &cdn.HealthProbeParametersArgs{
 * 				ProbeIntervalInSeconds: pulumi.Int(120),
 * 				ProbePath:              pulumi.String("/health.aspx"),
 * 				ProbeProtocol:          cdn.ProbeProtocolHttp,
 * 				ProbeRequestType:       cdn.HealthProbeRequestTypeGET,
 * 			},
 * 			OriginGroupName: pulumi.String("origingroup1"),
 * 			Origins: cdn.ResourceReferenceArray{
 * 				&cdn.ResourceReferenceArgs{
 * 					Id: pulumi.String("/subscriptions/subid/resourceGroups/RG/providers/Microsoft.Cdn/profiles/profile1/endpoints/endpoint1/origins/origin1"),
 * 				},
 * 			},
 * 			ProfileName:       pulumi.String("profile1"),
 * 			ResourceGroupName: pulumi.String("RG"),
 * 			ResponseBasedOriginErrorDetectionSettings: &cdn.ResponseBasedOriginErrorDetectionParametersArgs{
 * 				ResponseBasedDetectedErrorTypes:          cdn.ResponseBasedDetectedErrorTypesTcpErrorsOnly,
 * 				ResponseBasedFailoverThresholdPercentage: pulumi.Int(10),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.cdn.OriginGroup;
 * import com.pulumi.azurenative.cdn.OriginGroupArgs;
 * import com.pulumi.azurenative.cdn.inputs.HealthProbeParametersArgs;
 * import com.pulumi.azurenative.cdn.inputs.ResourceReferenceArgs;
 * import com.pulumi.azurenative.cdn.inputs.ResponseBasedOriginErrorDetectionParametersArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var originGroup = new OriginGroup("originGroup", OriginGroupArgs.builder()
 *             .endpointName("endpoint1")
 *             .healthProbeSettings(HealthProbeParametersArgs.builder()
 *                 .probeIntervalInSeconds(120)
 *                 .probePath("/health.aspx")
 *                 .probeProtocol("Http")
 *                 .probeRequestType("GET")
 *                 .build())
 *             .originGroupName("origingroup1")
 *             .origins(ResourceReferenceArgs.builder()
 *                 .id("/subscriptions/subid/resourceGroups/RG/providers/Microsoft.Cdn/profiles/profile1/endpoints/endpoint1/origins/origin1")
 *                 .build())
 *             .profileName("profile1")
 *             .resourceGroupName("RG")
 *             .responseBasedOriginErrorDetectionSettings(ResponseBasedOriginErrorDetectionParametersArgs.builder()
 *                 .responseBasedDetectedErrorTypes("TcpErrorsOnly")
 *                 .responseBasedFailoverThresholdPercentage(10)
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:cdn:OriginGroup origingroup1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Cdn/profiles/{profileName}/endpoints/{endpointName}/originGroups/{originGroupName}
 * ```
 */
public class OriginGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.cdn.OriginGroup,
) : KotlinCustomResource(javaResource, OriginGroupMapper) {
    /**
     * Health probe settings to the origin that is used to determine the health of the origin.
     */
    public val healthProbeSettings: Output<HealthProbeParametersResponse>?
        get() = javaResource.healthProbeSettings().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> healthProbeParametersResponseToKotlin(args0) })
            }).orElse(null)
        })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The source of the content being delivered via CDN within given origin group.
     */
    public val origins: Output<List<ResourceReferenceResponse>>
        get() = javaResource.origins().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    resourceReferenceResponseToKotlin(args0)
                })
            })
        })

    /**
     * Provisioning status of the origin group.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource status of the origin group.
     */
    public val resourceState: Output<String>
        get() = javaResource.resourceState().applyValue({ args0 -> args0 })

    /**
     * The JSON object that contains the properties to determine origin health using real requests/responses. This property is currently not supported.
     */
    public val responseBasedOriginErrorDetectionSettings:
        Output<ResponseBasedOriginErrorDetectionParametersResponse>?
        get() = javaResource.responseBasedOriginErrorDetectionSettings().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    responseBasedOriginErrorDetectionParametersResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Read only system data
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Time in minutes to shift the traffic to the endpoint gradually when an unhealthy endpoint comes healthy or a new endpoint is added. Default is 10 mins. This property is currently not supported.
     */
    public val trafficRestorationTimeToHealedOrNewEndpointsInMinutes: Output<Int>?
        get() =
            javaResource.trafficRestorationTimeToHealedOrNewEndpointsInMinutes().applyValue({ args0 ->
                args0.map({ args0 -> args0 }).orElse(null)
            })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object OriginGroupMapper : ResourceMapper<OriginGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.cdn.OriginGroup::class == javaResource::class

    override fun map(javaResource: Resource): OriginGroup = OriginGroup(
        javaResource as
            com.pulumi.azurenative.cdn.OriginGroup,
    )
}

/**
 * @see [OriginGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [OriginGroup].
 */
public suspend fun originGroup(name: String, block: suspend OriginGroupResourceBuilder.() -> Unit):
    OriginGroup {
    val builder = OriginGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [OriginGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun originGroup(name: String): OriginGroup {
    val builder = OriginGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}
